<div align="center">
  <h1 align="center">
    <img src="https://cndaqiang.github.io/wzry.doc/wzry.favicon.png" width="140">
    <br/>
    WZRY · 农活自动化助手
  </h1>
</div>
<div align="center">
  <img alt="WZRY Release" src="https://img.shields.io/github/v/release/cndaqiang/WZRY?style=flat-square&color=ff7fbf&label=WZRY" />
  <img alt="Stars" src="https://img.shields.io/github/stars/cndaqiang/WZRY?style=flat-square&color=66bb6a&label=Stars" />
  <img alt="Developer" src="https://img.shields.io/badge/cndaqiang-blue?style=flat-square&color=4096d8&label=Developer" />
</div>

<div align="center">
使用方法, 请访问: <a href="https://wzry-doc.pages.dev/guide/install/">安装指南</a>|<a href="https://wzrydoc.readthedocs.io/">备用指南</a>|<a href="https://www.bilibili.com/video/BV1JmcteBEUS">视频教程</a>.
<br/>
遇到问题, 请在提问前查看: <a href="https://wzry-doc.pages.dev/qa/qa/">常见问题</a>.
<br/>
</div>

## 免责声明
[WZRY](https://github.com/cndaqiang/WZRY) 是基于 [airtest-mobileauto](https://github.com/cndaqiang/airtest_mobileauto) 开发的王者荣耀农活自动化免费开源脚本。**7*24h 完全无人值守运行**，支持自动启动模拟器、更新游戏、错误自修复、全自动对战及礼包领取，解放双手专注生活。

> 本项目通过图像识别、模拟人手点击的方式实现自动化, 不会修改读取游戏数据。
>
> 虽然理论上没有封号风险，但使用本项目的后果需由用户自行承担。
>
> **本项目完全免费，且未在任何平台或渠道提供付费服务或收费支持。请勿相信任何形式的收费信息。**
> * ⚠️ **本项目不会在咸鱼、淘宝、拼多多等平台售卖，发现售卖请帮忙举报**⚠️
> * ⚠️ **本项目不允许以任何方式在咸鱼、淘宝、拼多多等平台售卖**⚠️


## 自动化

* 开启关闭模拟器、容器、手机
* 自动检测处理游戏闪退、模拟器关闭等各种错误
* 健康系统自动休息启动
* 自动切换熟练度,优先星耀人机模式,次数达到上限后切换青铜人机
* 自动调整分路并选择熟练度最低的英雄

## 对战模式

5v5人机匹配: 单人模式、组队模式、标准模式、快速模式、星耀难度、青铜难度

- 挂机模式: **全能**(击败、金牌、场次、**全英雄熟练度**)
- 触摸模式: 边走边普通攻击, 满足活动的**5v5标准对战非挂机**要求

王者模拟战单人模式、组队模式

- **刷信誉分专用**, 每日上限+5分. 
- 战令的每期任务: 20场娱乐模式, 可以用模拟战刷齐

隐藏模式

- **隐藏模式使用不当会扣信誉分**, 因此不写在项目主页
- 自行探索使用方法, **请为自己的行为负责**.

## 礼包功能

* 友情对战: 友情币领取、奖励兑换
* 邮件礼包: 好友邮件、系统邮件
* 妲己一键领奖
* 战令礼包、战令任务礼包
* 回忆礼册、灵宝互动
* 祈愿页面领取祈愿币、玉镖夺魁的飞镖
* 王者营地礼包
* 王者体验服礼包
* KPL观赛战令观赛领取经验升级
* 战队商店领取英雄碎片
* 商城每日免费钻石碎片随机礼包

## 致谢
- 灵感和支持来自以下项目：  
  - [airtest_mobileauto](https://github.com/cndaqiang/airtest_mobileauto)  
  - [WZRY_AirtestIDE](https://github.com/XRSec/WZRY_AirtestIDE)  
  - [Airtest Project](https://github.com/AirtestProject)
  - [StarRailAssistant](https://github.com/Starry-Wind/StarRailAssistant)
  - [March7thAssistant](https://github.com/moesnow/March7thAssistant)

- 感谢所有提问 issue 和为本项目打星的用户!
- 感谢b站的老哥们点赞推广!

## 开源协议

该项目采用 [GNU General Public License v3.0](https://www.gnu.org/licenses/gpl-3.0.html) 许可证进行开源。